@@ -33,32 +33,44 @@ Only necessary while parts of Twisted are unported.
 
 from __future__ import division
 
-from os import path
-
 
 modules = [
-    "twisted",
+    "twisted.__init__",
     "twisted._version",
-    "twisted.application",
+    "twisted.application.__init__",
     "twisted.application.app",
     "twisted.application.internet",
     "twisted.application.reactors",
     "twisted.application.service",
-    "twisted.application.test",
+    "twisted.application.strports",
+    "twisted.application.test.__init__",
+    "twisted.conch.__init__",
+    "twisted.conch.checkers",
+    "twisted.conch.error",
+    "twisted.conch.ssh.__init__",
+    "twisted.conch.ssh._cryptography_backports",
+    "twisted.conch.ssh.common",
+    "twisted.conch.ssh.keys",
+    "twisted.conch.ssh.sexpy",
+    "twisted.conch.telnet",
+    "twisted.conch.test.__init__",
     "twisted.copyright",
-    "twisted.cred",
+    "twisted.cred.__init__",
     "twisted.cred._digest",
     "twisted.cred.checkers",
     "twisted.cred.credentials",
     "twisted.cred.error",
     "twisted.cred.portal",
-    "twisted.cred.test",
-    "twisted.internet",
+    "twisted.cred.strcred",
+    "twisted.cred.test.__init__",
+    "twisted.internet.__init__",
     "twisted.internet._baseprocess",
     "twisted.internet._glibbase",
     "twisted.internet._newtls",
     "twisted.internet._posixstdio",
+    "twisted.internet._posixserialport",
     "twisted.internet._signals",
+    "twisted.internet._win32serialport",
     "twisted.internet.abstract",
     "twisted.internet.address",
     "twisted.internet.base",
@@ -79,20 +91,22 @@ modules = [
     "twisted.internet.protocol",
     "twisted.internet.reactor",
     "twisted.internet.selectreactor",
+    "twisted.internet.serialport",
     "twisted.internet.ssl",
     "twisted.internet.stdio",
     "twisted.internet.task",
     "twisted.internet.tcp",
-    "twisted.internet.test",
+    "twisted.internet.test.__init__",
     "twisted.internet.test._posixifaces",
     "twisted.internet.test.connectionmixins",
+    "twisted.internet.test.fakeendpoint",
     "twisted.internet.test.modulehelpers",
     "twisted.internet.test.reactormixins",
     "twisted.internet.threads",
     "twisted.internet.udp",
     "twisted.internet.unix",
     "twisted.internet.utils",
-    "twisted.logger",
+    "twisted.logger.__init__",
     "twisted.logger._buffer",
     "twisted.logger._file",
     "twisted.logger._filter",
@@ -107,38 +121,66 @@ modules = [
     "twisted.logger._observer",
     "twisted.logger._stdlib",
     "twisted.logger._util",
-    "twisted.logger.test",
-    "twisted.names",
+    "twisted.logger.test.__init__",
+    "twisted.names.__init__",
     "twisted.names._rfc1982",
-    "twisted.names._version",
+    "twisted.names.authority",
+    "twisted.names.secondary",
     "twisted.names.cache",
     "twisted.names.client",
     "twisted.names.common",
     "twisted.names.dns",
     "twisted.names.error",
     "twisted.names.hosts",
+    "twisted.names.server",
     "twisted.names.resolve",
-    "twisted.names.test",
-    "twisted.persisted",
+    "twisted.names.test.__init__",
+    "twisted.persisted.__init__",
     "twisted.persisted.aot",
     "twisted.persisted.crefutil",
     "twisted.persisted.sob",
     "twisted.persisted.styles",
     "twisted.plugin",
-    "twisted.plugins",
+    "twisted.plugins.__init__",
+    "twisted.plugins.cred_anonymous",
+    "twisted.plugins.cred_file",
+    "twisted.plugins.cred_memory",
+    "twisted.plugins.cred_sshkeys",
+    "twisted.plugins.cred_unix",
+    "twisted.plugins.twisted_core",
     "twisted.plugins.twisted_trial",
-    "twisted.positioning",
+    "twisted.plugins.twisted_reactors",
+    "twisted.plugins.twisted_web",
+    "twisted.positioning.__init__",
     "twisted.positioning._sentence",
     "twisted.positioning.base",
     "twisted.positioning.ipositioning",
     "twisted.positioning.nmea",
-    "twisted.protocols",
+    "twisted.protocols.__init__",
+    "twisted.protocols.amp",
     "twisted.protocols.basic",
     "twisted.protocols.policies",
-    "twisted.protocols.test",
+    "twisted.protocols.telnet",
+    "twisted.protocols.test.__init__",
+    "twisted.protocols.haproxy.__init__",
+    "twisted.protocols.haproxy._exceptions",
+    "twisted.protocols.haproxy._info",
+    "twisted.protocols.haproxy._interfaces",
+    "twisted.protocols.haproxy._v1parser",
+    "twisted.protocols.haproxy._v2parser",
+    "twisted.protocols.haproxy._wrapper",
+    "twisted.protocols.haproxy._parser",
+    "twisted.protocols.haproxy.test.__init__",
+    "twisted.protocols.haproxy.test.test_v1parser",
+    "twisted.protocols.haproxy.test.test_v2parser",
+    "twisted.protocols.haproxy.test.test_wrapper",
+    "twisted.protocols.haproxy.test.test_parser",
     "twisted.protocols.tls",
-    "twisted.python",
+    "twisted.python.__init__",
+    "twisted.python._appdirs",
     "twisted.python._tzhelper",
+    "twisted.python._oldstyle",
+    "twisted.python._url",
     "twisted.python.compat",
     "twisted.python.components",
     "twisted.python.constants",
@@ -146,6 +188,7 @@ modules = [
     "twisted.python.deprecate",
     "twisted.python.dist3",
     "twisted.python.failure",
+    "twisted.python.fakepwd",
     "twisted.python.filepath",
     "twisted.python.lockfile",
     "twisted.python.log",
@@ -154,6 +197,7 @@ modules = [
     "twisted.python.procutils",
     "twisted.python.randbytes",
     "twisted.python.reflect",
+    "twisted.python.roots",
     "twisted.python.runtime",
     "twisted.python.sendmsg",
     "twisted.python.systemd",
@@ -162,17 +206,21 @@ modules = [
     "twisted.python.test.modules_helpers",
     "twisted.python.threadable",
     "twisted.python.threadpool",
+    "twisted.python.url",
     "twisted.python.urlpath",
     "twisted.python.usage",
     "twisted.python.util",
     "twisted.python.versions",
-    "twisted.scripts",
+    "twisted.python.zippath",
+    "twisted.scripts.__init__",
+    "twisted.scripts._twistd_unix",
     "twisted.scripts.trial",
-    "twisted.test",
+    "twisted.scripts.twistd",
+    "twisted.test.__init__",
     "twisted.test.iosim",
     "twisted.test.proto_helpers",
     "twisted.test.ssl_helpers",
-    "twisted._threads",
+    "twisted._threads.__init__",
     "twisted._threads._convenience",
     "twisted._threads._ithreads",
     "twisted._threads._memory",
@@ -186,7 +234,7 @@ modules = [
     "twisted.trial.itrial",
     "twisted.trial.reporter",
     "twisted.trial.runner",
-    "twisted.trial.test",
+    "twisted.trial.test.__init__",
     "twisted.trial.test.detests",
     "twisted.trial.test.erroneous",
     "twisted.trial.test.packages",
@@ -195,7 +243,7 @@ modules = [
     "twisted.trial.test.suppression",
     "twisted.trial.unittest",
     "twisted.trial.util",
-    "twisted.web",
+    "twisted.web.__init__",
     "twisted.web._auth",
     "twisted.web._auth.basic",
     "twisted.web._auth.digest",
@@ -205,7 +253,7 @@ modules = [
     "twisted.web._newclient",
     "twisted.web._responses",
     "twisted.web._stan",
-    "twisted.web._version",
+    "twisted.web.demo",
     "twisted.web.error",
     "twisted.web.guard",
     "twisted.web.http_headers",
@@ -213,10 +261,13 @@ modules = [
     "twisted.web.resource",
     "twisted.web.script",
     "twisted.web.static",
+    "twisted.web.tap",
     "twisted.web.template",
-    "twisted.web.test",
+    "twisted.web.test.__init__",
     "twisted.web.test.requesthelper",
     "twisted.web.util",
+    "twisted.web.vhost",
+    "twisted.web.wsgi",
     "twisted.web.xmlrpc",
 ]
 
@@ -225,10 +276,14 @@ modules = [
 testModules = [
     "twisted.application.test.test_internet",
     "twisted.application.test.test_service",
+    "twisted.conch.test.test_checkers",
+    "twisted.conch.test.test_keys",
+    "twisted.conch.test.test_telnet",
     "twisted.cred.test.test_cramauth",
     "twisted.cred.test.test_cred",
     "twisted.cred.test.test_digestauth",
     "twisted.cred.test.test_simpleauth",
+    "twisted.cred.test.test_strcred",
     "twisted.internet.test.test_abstract",
     "twisted.internet.test.test_address",
     "twisted.internet.test.test_base",
@@ -248,6 +303,7 @@ testModules = [
     "twisted.internet.test.test_posixprocess",
     "twisted.internet.test.test_process",
     "twisted.internet.test.test_protocol",
+    "twisted.internet.test.test_serialport",
     "twisted.internet.test.test_sigchld",
     "twisted.internet.test.test_stdio",
     "twisted.internet.test.test_tcp",
@@ -276,13 +332,17 @@ testModules = [
     "twisted.names.test.test_dns",
     "twisted.names.test.test_hosts",
     "twisted.names.test.test_rfc1982",
+    "twisted.names.test.test_server",
     "twisted.names.test.test_util",
+    "twisted.names.test.test_names",
+    "twisted.names.test.test_examples",
     "twisted.persisted.test.test_styles",
     "twisted.positioning.test.test_base",
     "twisted.positioning.test.test_nmea",
     "twisted.positioning.test.test_sentence",
     "twisted.protocols.test.test_basic",
     "twisted.protocols.test.test_tls",
+    "twisted.python.test.test_appdirs",
     "twisted.python.test.test_components",
     "twisted.python.test.test_constants",
     "twisted.python.test.test_deprecate",
@@ -291,10 +351,13 @@ testModules = [
     "twisted.python.test.test_sendmsg",
     "twisted.python.test.test_systemd",
     "twisted.python.test.test_tzhelper",
+    "twisted.python.test.test_url",
     "twisted.python.test.test_urlpath",
     "twisted.python.test.test_util",
     "twisted.python.test.test_versions",
+    "twisted.python.test.test_zippath",
     "twisted.test.test_abstract",
+    "twisted.test.test_amp",
     "twisted.test.test_application",
     "twisted.test.test_compat",
     "twisted.test.test_context",
@@ -311,29 +374,32 @@ testModules = [
     "twisted.test.test_iutils",
     "twisted.test.test_lockfile",
     "twisted.test.test_log",
+    "twisted.test.test_logfile",
     "twisted.test.test_loopback",
     "twisted.test.test_modules",
     "twisted.test.test_monkey",
+    "twisted.test.test_nooldstyle",
     "twisted.test.test_paths",
-    "twisted.test.test_plugin",
     "twisted.test.test_persisted",
+    "twisted.test.test_plugin",
     "twisted.test.test_policies",
     "twisted.test.test_process",
     "twisted.test.test_randbytes",
     "twisted.test.test_reflect",
-    "twisted.test.test_setup",
+    "twisted.test.test_roots",
     "twisted.test.test_sob",
     "twisted.test.test_ssl",
     "twisted.test.test_sslverify",
     "twisted.test.test_stdio",
+    "twisted.test.test_strports",
     "twisted.test.test_task",
     "twisted.test.test_tcp",
     "twisted.test.test_tcp_internals",
     "twisted.test.test_threadable",
     "twisted.test.test_threadpool",
     "twisted.test.test_threads",
-    "twisted.test.test_twisted",
     "twisted.test.test_twistd",
+    "twisted.test.test_twisted",
     "twisted.test.test_udp",
     "twisted.test.test_unix",
     "twisted.test.test_usage",
@@ -360,40 +426,46 @@ testModules = [
     "twisted.trial.test.test_util",
     "twisted.trial.test.test_warning",
     "twisted.web.test._util",
+    "twisted.web.test.test_agent",
     "twisted.web.test.test_error",
     # The downloadPage tests weren't ported:
     "twisted.web.test.test_http",
     "twisted.web.test.test_flatten",
-    "twisted.web.test.test_httpauth",
     "twisted.web.test.test_http_headers",
+    "twisted.web.test.test_httpauth",
     "twisted.web.test.test_newclient",
     "twisted.web.test.test_proxy",
     "twisted.web.test.test_resource",
     "twisted.web.test.test_script",
     "twisted.web.test.test_stan",
     "twisted.web.test.test_static",
+    "twisted.web.test.test_tap",
     "twisted.web.test.test_template",
     "twisted.web.test.test_util",
     "twisted.web.test.test_web",
     "twisted.web.test.test_web__responses",
     "twisted.web.test.test_webclient",
+    "twisted.web.test.test_vhost",
+    "twisted.web.test.test_wsgi",
     "twisted.web.test.test_xmlrpc",
 ]
 
 
 testDataFiles = [
+    "twisted.conch.test.keydata",
     "twisted.internet.test.process_cli",
     "twisted.internet.test.process_helper",
     "twisted.positioning.test.receiver",
     "twisted.python.test.pullpipe",
     "twisted.python.test.pullpipe",
-    "twisted.test._preamble",
     "twisted.test.plugin_basic",
     "twisted.test.plugin_extra1",
     "twisted.test.plugin_extra2",
     "twisted.test.process_cmdline",
     "twisted.test.process_echoer",
     "twisted.test.process_fds",
+    "twisted.test.process_getargv",
+    "twisted.test.process_getenv",
     "twisted.test.process_linger",
     "twisted.test.process_reader",
     "twisted.test.process_signal",
@@ -417,6 +489,10 @@ testDataFiles = [
     "twisted.trial.test.packages",
     "twisted.trial.test.sample",
     "twisted.trial.test.scripttest",
+    "twisted.trial.test.weird",
+    "twisted.trial.test.mockcustomsuite",
+    "twisted.trial.test.mockcustomsuite2",
+    "twisted.trial.test.mockcustomsuite3",
 ]
 
 
@@ -430,12 +506,6 @@ almostModules = [
     "twisted.names.root",
     # Echo is ported for twisted.application tests:
     "twisted.protocols.wire",
-    # Required by twisted.test.test_twistd, which tests twisted.application:
-    "twisted.scripts.twistd",
-    "twisted.scripts._twistd_unix",
-    # Required by twisted.test.test_twistd
-    # https://twistedmatrix.com/trac/ticket/7958
-    "twisted.python.fakepwd",
     # Missing test coverage:
     "twisted.protocols.loopback",
     # Minimally used by setup3.py:
@@ -461,30 +531,6 @@ almostModules = [
     "twisted.web.server",
 ]
 
-
-def _processDataFileList(dataFiles):
-    """
-    Turn a list of file names into a format that distutils likes.
-
-    For example:
-
-        ["foo/bar.py", "baz/spam.py"]
-
-    ...is transformed into...
-
-        [("foo", ["foo/bar.py"]), ("baz", "baz/spam.py")]
-    """
-    files = {}
-
-    for file in dataFiles:
-        pathFragments = file.split(".")
-        targetDir = path.sep.join(pathFragments[:-1])
-
-        if not files.get(targetDir):
-            files[targetDir] = []
-        files[targetDir].append(path.sep.join(pathFragments) + ".py")
-
-    return list(files.items())
-
-
 modulesToInstall = modules + testModules + almostModules
+
+portedScripts = ["bin/trial", "bin/twistd"]
